@@ -2,21 +2,24 @@
  * Copyright (c) 2000 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
- *
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
- *
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * 
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * 
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
- *
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
+ * 
  * @APPLE_LICENSE_HEADER_END@
  */
 
@@ -33,6 +36,7 @@
 #include <IOKit/IOMemoryDescriptor.h>
 #include <IOKit/IOCommandGate.h>
 #include <IOKit/IOWorkLoop.h>
+#include <IOKit/ata/IOATATypes.h>
 #include <IOKit/ata/IOATADevConfig.h>
 #include <IOKit/ata/IOATABusInfo.h>
 #include <IOKit/ata/IOATACommand.h>
@@ -544,7 +548,7 @@ IOATAPIProtocolTransport::SendSCSICommand ( SCSITaskIdentifier request,
 	UInt64							requestCount 		= 0;
 	UInt32							timeoutDuration		= 0;
 	bool							shouldUseDMA		= true;
-
+	
 	STATUS_LOG ( ( "IOATAPIProtocolTransport::SendSCSICommand called\n" ) );
     
 	if ( OSBitOrAtomic ( kATAPICommandBusyMask, &fSemaphore ) & kATAPICommandBusyMask )
@@ -578,7 +582,7 @@ IOATAPIProtocolTransport::SendSCSICommand ( SCSITaskIdentifier request,
 	clientData 			= ( ATAPIClientData * ) cmd->refCon;	
 	*serviceResponse 	= kSCSIServiceResponse_Request_In_Process;
 	*taskStatus			= kSCSITaskStatus_No_Status;
-
+	
 	if ( fPhysicallyConnected == false )
 	{
 		
@@ -1428,7 +1432,7 @@ IOATAPIProtocolTransport::GetATACommandObject ( bool blockForCommand )
 	IOATACommand *		cmd	= NULL;
 	
 	STATUS_LOG ( ( "IOATAPIProtocolTransport::GetATACommandObject entering.\n" ) );
-		
+	
 	cmd = ( IOATACommand * ) fCommandPool->getCommand ( blockForCommand );
 	
 	return cmd;
@@ -1905,7 +1909,7 @@ IOATAPIProtocolTransport::EnablePollingOfStatusRegister ( void )
 	AbsoluteTime	time;
 	
 	STATUS_LOG ( ( "EnablePollingOfStatusRegister called\n" ) );
-		
+	
 	// No reason to start a thread if we've been termintated	
 	if ( ( isInactive ( ) == false ) &&
 		 ( fPollingThread != NULL ) &&
